# universal_auth/client.py

from typing import Optional
import requests

class LicenseClient:
    def __init__(self, endpoint: str, product: Optional[str] = None):
        self.endpoint = endpoint.rstrip("/")
        self.product = product

    def validate_key(self, key: str) -> bool:
        if not key:
            raise ValueError("License key cannot be empty")

        payload = {"key": key}
        if self.product:
            payload["product"] = self.product

        try:
            response = requests.post(self.endpoint, json=payload, timeout=5)
            response.raise_for_status()
            data = response.json()
            return data.get("valid", False)
        except requests.exceptions.RequestException as e:
            print(f"Request failed: {e}")
            return False

    def get_license_data(self, key: str) -> Optional[dict]:
        payload = {"key": key}
        if self.product:
            payload["product"] = self.product

        try:
            response = requests.post(self.endpoint, json=payload, timeout=5)
            response.raise_for_status()
            return response.json()
        except requests.exceptions.RequestException as e:
            print(f"Request failed: {e}")
            return None
